package com.mc.monkeynes.gui;

import com.mc.monkeynes.base.*;
import com.mc.monkeynes.hardware.*;

import java.awt.*;
import java.awt.event.*;
//import java.util.*;
import javax.swing.*;
import javax.swing.event.*;



public class MonkeyNesGui
{
  private JFrame             mainFrame                        = new JFrame();
  private JFileChooser       fileChooser                      = null;
  private GenericFileFilter  romTypeFilter                    = new GenericFileFilter( "nes", "NES ROM Files (*.nes)", true );
  
  // Menu System
  private JMenuBar           mainMenu                         = new JMenuBar();
  private JMenu              fileMenu                         = new JMenu( "File" );
  private JMenuItem          fileOpenMenuItem                 = new JMenuItem( "Open ROM", KeyEvent.VK_O );
  private JMenuItem          fileExitMenuItem                 = new JMenuItem( "Exit", KeyEvent.VK_X );
  private JMenu              helpMenu                         = new JMenu( "Help" );
  private JMenuItem          helpAboutMenuItem                = new JMenuItem( "About", KeyEvent.VK_A );
  
  // Status label
  private JLabel             statusLabel                      = new JLabel( "Idle" );
  
  public MonkeyNesGui()
  {
    // Put the menu system together
    fileMenu.setMnemonic( KeyEvent.VK_F );
    fileMenu.add( fileOpenMenuItem );
    fileMenu.add( fileExitMenuItem );
    helpMenu.setMnemonic( KeyEvent.VK_H );
    helpMenu.add( helpAboutMenuItem );

    // create the actual menu bar
    mainMenu.add( fileMenu );
    mainMenu.add( helpMenu );
    
    // Configure the FileChooser
    fileChooser = new JFileChooser();
    fileChooser.setMultiSelectionEnabled( false );    
    fileChooser.addChoosableFileFilter( romTypeFilter );
    
    // Build the main view
    mainFrame.getContentPane().add( mainMenu,     BorderLayout.NORTH  );
    mainFrame.getContentPane().add( statusLabel,  BorderLayout.SOUTH );
    
    
    // ----------------------------------------------------------------------------
    // ----------------------------------------------------------------------------
    // ADD Listeners
    // ----------------------------------------------------------------------------
    // ----------------------------------------------------------------------------
    
    // Main window closing listener
    mainFrame.addWindowListener( new WindowAdapter()
    {
      public void windowClosing( WindowEvent we )
      {
        shutDown();
      }
    } );
    
    // File->Open menu listener
    fileOpenMenuItem.addActionListener( new ActionListener()
    {
      public void actionPerformed( ActionEvent ae )
      {
        openRom();
      }
    } );
    
    // File->Exit menu listener
    fileExitMenuItem.addActionListener( new ActionListener()
    {
      public void actionPerformed( ActionEvent ae )
      {
        shutDown();
      }
    } );
    
    // Help->About menu listener
    helpAboutMenuItem.addActionListener( new ActionListener()
    {
      public void actionPerformed( ActionEvent ae )
      {
        helpAbout();
      }
    } );
    
  } // End of constructor ----------------------------------------------------------
  
  // Helper methods
  private void shutDown()
  {
    // For now just can everything...
    System.exit(0);
  }

  private void openRom()
  {
    fileChooser.setFileSelectionMode( JFileChooser.FILES_AND_DIRECTORIES );
    if( fileChooser.showOpenDialog( mainFrame ) == JFileChooser.APPROVE_OPTION )
    {
      NesRom rom = NesRomLoader.loadRomFile( fileChooser.getSelectedFile().getPath() );
      System.out.println( rom );
    }
  }

  private void helpAbout()
  {
    // helpAboutBox.show();
  }  
  
  public void show()
  {
    // Position the window
    mainFrame.setLocation( new Point( 0, 0 ) );

    // Size the window
    mainFrame.setSize( 400, 400 );

    // Set the title
    mainFrame.setTitle( "MonkeyNES" );

    // Show the whole mess...
    mainFrame.setVisible( true );
  }
  
}